==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/representations/ConstantObject.h <==
// public abstract class soot.jimple.toolkits.pointer.representations.ConstantObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eaf7ad7a888244a0 soot_jimple_toolkits_pointer_representations_ConstantObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_representations_ConstantObject_H_
#define _JC_soot_jimple_toolkits_pointer_representations_ConstantObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$shortString$fc1f709a9c723fa1;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods {
	struct _jc_java_lang_String$object	*(*shortString$fc1f709a9c723fa1)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods	soot_jimple_toolkits_pointer_representations_ConstantObject;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs {
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs	soot_jimple_toolkits_pointer_representations_ConstantObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs	soot_jimple_toolkits_pointer_representations_ConstantObject;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object {
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_representations_ConstantObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_representations_ConstantObject_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/representations/ConstantObject.h <==
// public abstract class soot.jimple.toolkits.pointer.representations.ConstantObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eaf7ad7a888244a0 soot_jimple_toolkits_pointer_representations_ConstantObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_representations_ConstantObject_H_
#define _JC_soot_jimple_toolkits_pointer_representations_ConstantObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$shortString$fc1f709a9c723fa1(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$shortString$fc1f709a9c723fa1;
extern _jc_method _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods {
	struct _jc_java_lang_String$object	*(*shortString$fc1f709a9c723fa1)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vmethods	soot_jimple_toolkits_pointer_representations_ConstantObject;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs {
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_refs	soot_jimple_toolkits_pointer_representations_ConstantObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$sub_nonrefs	soot_jimple_toolkits_pointer_representations_ConstantObject;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$object {
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_representations_ConstantObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$vtype _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_representations_ConstantObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_representations_ConstantObject$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_representations_ConstantObject_H_ */
